import pygame
import os

MAIN_DIR = os.path.split(os.path.abspath(__file__))[0]

def load_img(name):
    path = os.path.join(MAIN_DIR ,'../images', name)
    return pygame.image.load(path)

def load_font(name, size):
  path = os.path.join(MAIN_DIR, '../fonts', name)
  return pygame.font.Font(path, size)



import pygame
from . import tools

class Donkey(pygame.sprite.Sprite):
    def __init__(self, MIN_HEIGHT, SPEED_JUMP, GRAVITY):
        pygame.sprite.Sprite.__init__(self)

        self.images_walk = [tools.load_img('animations/Andar (1).png').convert_alpha(),
                            tools.load_img('animations/Andar (2).png').convert_alpha(),
                            tools.load_img('animations/Andar (3).png').convert_alpha(),
                            tools.load_img('animations/Andar (4).png').convert_alpha(),
                            tools.load_img('animations/Andar (5).png').convert_alpha(),
                            tools.load_img('animations/Andar (6).png').convert_alpha()]

        self.images_jump = [tools.load_img('animations/Jump (1).png').convert_alpha(),
                            tools.load_img('animations/Jump (2).png').convert_alpha(),
                            tools.load_img('animations/Jump (3).png').convert_alpha(),
                            tools.load_img('animations/Jump (4).png').convert_alpha(),
                            tools.load_img('animations/Jump (5).png').convert_alpha()]

        self.speed = SPEED_JUMP
        self.isJumping = False
        self.IMAGE_INTERVAL = 110
        self.last_update = 0
        self.current_image = 0
        self.current_list = self.images_walk
        self.image = tools.load_img('original.png').convert_alpha()
        self.rect = self.image.get_rect()
        self.rect[0] = 20
        self.rect[1] = MIN_HEIGHT

    def update(self, GRAVITY, MIN_HEIGHT):
        if self.isJumping:
            self.current_list = self.images_jump
        else:
            self.current_list = self.images_walk

        if self.current_list == self.images_jump:
            if pygame.time.get_ticks() - self.last_update > self.IMAGE_INTERVAL:
                self.current_image = (self.current_image + 1) % len(self.current_list)
                self.image = self.current_list[self.current_image]
                self.last_update = pygame.time.get_ticks()
        else:
            self.current_image = (self.current_image + 1) % len(self.current_list)
            self.image = self.current_list[self.current_image]

        self.speed += GRAVITY
        self.rect[1] += self.speed

        if self.rect[1] > MIN_HEIGHT:
            self.rect[1] = MIN_HEIGHT
            self.speed = 0
            self.isJumping = False

    def jump(self, SPEED_JUMP, MIN_HEIGHT):
        if self.rect[1] == MIN_HEIGHT:
            self.speed -= SPEED_JUMP
            self.current_image = 0
            self.isJumping = True
    
    def down(self, SPEED_JUMP, MIN_HEIGHT, GRAVITY):
        if self.rect[1] < MIN_HEIGHT:
            self.speed += SPEED_JUMP + GRAVITY



import pygame
import random
from .donkey import Donkey
from .ground import Ground
from .obstacles import Obstacles
from .scoreboard import Scoreboard
from . import tools


def game():
    pygame.display.set_caption("Donkey Kong: Bird Island")

    pygame.font.init()

    SCREEN_WIDTH = 800
    SCREEN_HEIGHT = 350
    GAME_SPEED = 16
    SPEED_JUMP = 50
    GRAVITY = 9
    GROUND_WIDTH = 2 * SCREEN_WIDTH
    GROUND_HEIGHT = 35
    MIN_HEIGHT = 228

    def is_off_screen(sprite):
        return sprite.rect[0] < -(sprite.rect[2])

    def get_random(sprite, width):
        return sprite.rect[0] <= width

    pygame.init()

    screen = pygame.display.set_mode((SCREEN_WIDTH, SCREEN_HEIGHT))
    BACKGROUND = tools.load_img("background.png")

    # Defining groups and instantiating objects
    donkey_group = pygame.sprite.Group()
    donkey = Donkey(MIN_HEIGHT, SPEED_JUMP, GRAVITY)
    donkey_group.add(donkey)

    ground_group = pygame.sprite.Group()
    for i in range(2):
        ground = Ground(GROUND_WIDTH * i, GROUND_WIDTH, GROUND_HEIGHT, GAME_SPEED, SCREEN_HEIGHT)
        ground_group.add(ground)

    obstacle_group = pygame.sprite.Group()
    obstacle = Obstacles(800, SCREEN_HEIGHT, GROUND_HEIGHT, GAME_SPEED)
    obstacle_group.add(obstacle)

    scb = Scoreboard()

    clock = pygame.time.Clock()

    # Main loop
    verify = True
    running = True
    count = 0
    while running:
        for event in pygame.event.get():
            if event.type == pygame.QUIT:
                running = False

            if event.type == pygame.KEYDOWN:
                if event.key == pygame.K_UP:
                    donkey.jump(SPEED_JUMP, MIN_HEIGHT)

                if event.key == pygame.K_DOWN:
                    donkey.down(SPEED_JUMP, MIN_HEIGHT, GRAVITY)

        screen.blit(BACKGROUND, (0, 0))

        # Adds a new ground and remove
        if is_off_screen(ground_group.sprites()[0]):
            new_ground = Ground(ground_group.sprites()[1].rect[0] + GROUND_WIDTH, GROUND_WIDTH, GROUND_HEIGHT, GAME_SPEED, SCREEN_HEIGHT)
            ground_group.add(new_ground)
            ground_group.remove(ground_group.sprites()[0])

        # Removes obstacles
        if len(obstacle_group.sprites()) > 0 and is_off_screen(obstacle_group.sprites()[0]):
            obstacle_group.remove(obstacle_group.sprites()[0])
            verify = True
        
        # Check if the distance between the obstacles is correct
        if get_random(obstacle_group.sprites()[0], 300) and verify:
            verify = False
            new_obstacle1 = Obstacles(random.randint(800, 1300), SCREEN_HEIGHT, GROUND_HEIGHT, GAME_SPEED)
            obstacle_group.add(new_obstacle1)

        #Acceleration
        acceleration = 0
        if GAME_SPEED < 60:
            if count == 100:
                acceleration = 1
            elif count == 200:
                acceleration = 2
                count = 0
            GAME_SPEED += acceleration
            count += 1



        scb.update()
        donkey_group.update(GRAVITY, MIN_HEIGHT)
        obstacle_group.update(GAME_SPEED)
        ground_group.update(GAME_SPEED)

        scb.draw(screen)
        donkey_group.draw(screen)
        obstacle_group.draw(screen)
        ground_group.draw(screen)

        pygame.display.update()

        #Collision 
        if pygame.sprite.groupcollide(donkey_group, obstacle_group, False, False, pygame.sprite.collide_mask):
            break

        clock.tick(20)

        
    pygame.quit()




import pygame
from . import tools

class Ground(pygame.sprite.Sprite):
    def __init__(self, xpos, GROUND_WIDTH, GROUND_HEIGHT, GAME_SPEED, SCREEN_HEIGHT):
        pygame.sprite.Sprite.__init__(self)

        self.image = tools.load_img('ground.fw.png')
        self.image = pygame.transform.scale(self.image, (GROUND_WIDTH, GROUND_HEIGHT))

        self.rect = self.image.get_rect()
        self.rect[0] = xpos
        self.rect[1] = SCREEN_HEIGHT - GROUND_HEIGHT

    def update(self, GAME_SPEED):
        self.rect[0] -= GAME_SPEED



import pygame
from random import randrange
from . import tools

class Obstacles(pygame.sprite.Sprite):
    def __init__(self, xpos, SCREEN_HEIGHT, GROUND_HEIGHT, GAME_SPEED):
        pygame.sprite.Sprite.__init__(self)

        self.images = [tools.load_img('snake1.png').convert_alpha(),
                        tools.load_img('barris.png').convert_alpha(),
                        tools.load_img('mouse.png').convert_alpha()]

        range = randrange(0, len(self.images))

        self.image = self.images[range]
        if range == 0:
            self.image = pygame.transform.scale(self.image, (40, 70))
        elif range == 1:
            self.image = pygame.transform.scale(self.image, (73, 70))

        self.rect = self.image.get_rect()
        self.rect[0] = xpos
        self.rect[1] = SCREEN_HEIGHT - GROUND_HEIGHT - self.rect[3]

    def update(self, GAME_SPEED):
        self.rect[0] -= GAME_SPEED



from . import tools


class Scoreboard:
    def __init__(self):
        self.score = '00000'
        self.font = tools.load_font('Jumpman.ttf', 32)

    def update(self):
        self.score = int(self.score) + 1
        self.score = f'{self.score:05}'
        self.scoreboard = self.font.render(self.score, True, (255, 255, 255))

    def draw(self, screen):
        screen.blit(self.scoreboard, (720, 0))


from setuptools import setup, find_packages

with open("README.md", "r") as fread:
    long_description = fread.read()

setup(
    name="dkbirdisland",
    version="0.1.3.dev",
    author="Murilo Castro",
    author_email="murilo.castro@ccc.ufcg.edu.br",
    description="DK, T-rex style",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/Murilo-Gruppi/DonkeyKong-BirdIsland",
    packages=find_packages(),
    include_package_data=True,
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
    install_requires=['pygame>=2.0'],
    entry_points={
        'console_scripts': [
            'dkbirdisland = dkbirdisland.__main__:main'
        ]
    }
)

